@@ -5,8 +5,9 @@ import json
 from typing import Any, Dict
 
 # Location of biobricks
-BASE_DIR = '~/biobricks'
+BASE_DIR = os.path.expanduser('~')+'/biobricks'
 CONFIG_FILE = BASE_DIR+'/config.json'
+library = None
 
 # Current version
 def version():
@@ -26,10 +27,11 @@ def write_config(config: Dict[str, Any]) -> None:
         json.dump(config, f)
 
 def initialize() -> None:
+    global library
     os.makedirs(BASE_DIR, exist_ok=True)
     if exists(CONFIG_FILE):
         config = read_config()
-        globals().update(config)
+        library = config["library"]
         print(f"BioBricks library already intialized to {library}.")
     else:
         bblib = os.getenv("bblib")
@@ -37,13 +39,10 @@ def initialize() -> None:
             library = bblib
         else:
             library = BASE_DIR+'/library'
-        config = {
-            'library': library,
-        }
+        config = { 'library': library, }
         write_config(config)
         os.makedirs(library, exist_ok=True)
         os.makedirs(library+"/cache", exist_ok=True)
         if not exists(library+"/.git"):
             os.system(f"cd {library}; git init")
-        globals().update(config)
         print(f"Initialized BioBricks library to {library}.")
